<?php
/*
Plugin Name: Clutter-Free
Version: 0.2
Plugin URI: http://txfx.net/code/wordpress/clutter-free/
Description: Allows you to hide portions of the WordPress interface that you seldom use.  Requires WP 2.0.5 or above.
Author: Mark Jaquith
Author URI: http://txfx.net/
*/


function txfx_clutter_free_validate($id) {
	$css_ids = array_keys(txfx_clutter_free_ids());
	if ( in_array($id, $css_ids) )
		return true;
	return false;
}


function txfx_clutter_free_ids() {
	return array(
		'commentstatusdiv' => __('Comment Status', 'clutter-free'),
		'passworddiv' => __('Password', 'clutter-free'),
		'slugdiv' => __('Slug', 'clutter-free'),
		'categorydiv' => __('Categories', 'clutter-free'),
		'authordiv' => __('Author', 'clutter-free'),
		'poststatusdiv' => __('Post Status', 'clutter-free'),
		'posttimestampdiv' => __('Timestamp', 'clutter-free'),
		'trackbacksdiv' => __('Trackbacks', 'clutter-free'),
		'uploading' => __('Image Upload', 'clutter-free'),
		'quicktags' => __('Quicktags', 'clutter-free'),
		'postexcerpt' => __('Excerpt', 'clutter-free'),
		'postcustom' => __('Custom Fields', 'clutter-free'),
		'wp-bookmarklet' => __('Bookmarklet', 'clutter-free'),
		'footer' => __('Footer', 'clutter-free')
		);
}


function txfx_clutter_free_css() {
	$user = wp_get_current_user();

	$options = get_user_option('txfx_clutter_free');
	if ( !$options ) {
		$options = array_map(create_function('$a', 'return "1";'), txfx_clutter_free_ids());
		update_user_option($user->ID, 'txfx_clutter_free', $options);
	}
	$css_hidden_ids = array();
	foreach ( (array) $options as $id => $val ) {
		if ( 0 == $val && txfx_clutter_free_validate($id) )
			$css_hidden_ids[] = '#' . $id;
	}
	if ( !$css_hidden_ids ) {
		echo '<!-- none blocked -->';
		return;
	}
	$css_id_string = implode(', ', $css_hidden_ids);
	echo "\n<style type='text/css'>\n<!--\n$css_id_string { display: none !important; }\n-->\n</style>\n";
}


function txfx_clutter_free_options() {
		$options = get_user_option('txfx_clutter_free'); 
		$css_ids = txfx_clutter_free_ids();
	?>
	<p><?php _e('Display the following elements on the post screen:', 'clutter-free'); ?></p>
	<ul>
	<?php foreach ( $css_ids as $css_id => $css_id_name ) { ?>
		<li><label for="txfx_clutter_free_<?php echo $css_id; ?>"><input name="txfx_clutter_free[<?php echo $css_id; ?>]" id="txfx_clutter_free_<?php echo $css_id; ?>" type="checkbox" value="1" <?php checked('1', $options[$css_id]); ?> />
			<?php echo $css_id_name; ?></label></li>
	<?php } ?>
	</ul>
	<?php
}


function txfx_clutter_free_update() {
	$user = wp_get_current_user();
	$updated_css_ids = array();
	$css_ids = array_keys(txfx_clutter_free_ids());
	foreach ( $css_ids as $css_id )
		$updated_css_ids[$css_id] = ( $_POST['txfx_clutter_free'][$css_id] ) ? '1' : '0';
	update_user_option($user->ID, 'txfx_clutter_free', $updated_css_ids);
}


add_action('admin_head', 'txfx_clutter_free_css');
add_action('profile_personal_options', 'txfx_clutter_free_options');
add_action('personal_options_update', 'txfx_clutter_free_update');
add_action('init', create_function('$a=0','load_plugin_textdomain("clutter-free");'));
?>